==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/DerivedAssociationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsDerivedOneSideSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsDerivedOtherSideSet;
import io.ciera.tool.sql.ooaofooa.association.DerivedAssociation;
import io.ciera.tool.sql.ooaofooa.association.DerivedAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsDerivedOneSideSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsDerivedOtherSideSetImpl;

import java.util.Arrays;
import java.util.List;


public class DerivedAssociationSetImpl extends InstanceSet<DerivedAssociationSet,DerivedAssociation> implements DerivedAssociationSet {

    // attributes
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( DerivedAssociation derivedassociation : this ) derivedassociation.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setRel_Chn( String m_Rel_Chn ) throws XtumlException {
        for ( DerivedAssociation derivedassociation : this ) derivedassociation.setRel_Chn( m_Rel_Chn );
    }


    // selections
    @Override
    public AssociationSet R206_is_a_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( DerivedAssociation derivedassociation : this ) associationset.add( derivedassociation.R206_is_a_Association() );
        return associationset;
    }
    @Override
    public ClassAsDerivedOneSideSet R214_relates_ClassAsDerivedOneSide() throws XtumlException {
        ClassAsDerivedOneSideSet classasderivedonesideset = new ClassAsDerivedOneSideSetImpl();
        for ( DerivedAssociation derivedassociation : this ) classasderivedonesideset.add( derivedassociation.R214_relates_ClassAsDerivedOneSide() );
        return classasderivedonesideset;
    }
    @Override
    public ClassAsDerivedOtherSideSet R215_relates_ClassAsDerivedOtherSide() throws XtumlException {
        ClassAsDerivedOtherSideSet classasderivedothersideset = new ClassAsDerivedOtherSideSetImpl();
        for ( DerivedAssociation derivedassociation : this ) classasderivedothersideset.add( derivedassociation.R215_relates_ClassAsDerivedOtherSide() );
        return classasderivedothersideset;
    }


    @Override
    public DerivedAssociation nullElement() {
        return DerivedAssociationImpl.EMPTY_DERIVEDASSOCIATION;
    }

    @Override
    public DerivedAssociationSet emptySet() {
      return new DerivedAssociationSetImpl();
    }

    @Override
    public DerivedAssociationSet value() {
        return this;
    }

    @Override
    public List<DerivedAssociation> elements() {
        return Arrays.asList(toArray(new DerivedAssociation[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/DerivedAssociationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsDerivedOneSideSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsDerivedOtherSideSet;
import io.ciera.tool.sql.ooaofooa.association.DerivedAssociation;
import io.ciera.tool.sql.ooaofooa.association.DerivedAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsDerivedOneSideSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsDerivedOtherSideSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class DerivedAssociationSetImpl extends InstanceSet<DerivedAssociationSet,DerivedAssociation> implements DerivedAssociationSet {

    public DerivedAssociationSetImpl() {
    }

    public DerivedAssociationSetImpl(Comparator<? super DerivedAssociation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setRel_Chn( String m_Rel_Chn ) throws XtumlException {
        for ( DerivedAssociation derivedassociation : this ) derivedassociation.setRel_Chn( m_Rel_Chn );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( DerivedAssociation derivedassociation : this ) derivedassociation.setRel_ID( ref_Rel_ID );
    }


    // selections
    @Override
    public AssociationSet R206_is_a_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( DerivedAssociation derivedassociation : this ) associationset.add( derivedassociation.R206_is_a_Association() );
        return associationset;
    }
    @Override
    public ClassAsDerivedOneSideSet R214_relates_ClassAsDerivedOneSide() throws XtumlException {
        ClassAsDerivedOneSideSet classasderivedonesideset = new ClassAsDerivedOneSideSetImpl();
        for ( DerivedAssociation derivedassociation : this ) classasderivedonesideset.add( derivedassociation.R214_relates_ClassAsDerivedOneSide() );
        return classasderivedonesideset;
    }
    @Override
    public ClassAsDerivedOtherSideSet R215_relates_ClassAsDerivedOtherSide() throws XtumlException {
        ClassAsDerivedOtherSideSet classasderivedothersideset = new ClassAsDerivedOtherSideSetImpl();
        for ( DerivedAssociation derivedassociation : this ) classasderivedothersideset.add( derivedassociation.R215_relates_ClassAsDerivedOtherSide() );
        return classasderivedothersideset;
    }


    @Override
    public DerivedAssociation nullElement() {
        return DerivedAssociationImpl.EMPTY_DERIVEDASSOCIATION;
    }

    @Override
    public DerivedAssociationSet emptySet() {
      return new DerivedAssociationSetImpl();
    }

    @Override
    public DerivedAssociationSet emptySet(Comparator<? super DerivedAssociation> comp) {
      return new DerivedAssociationSetImpl(comp);
    }

    @Override
    public DerivedAssociationSet value() {
        return this;
    }

    @Override
    public List<DerivedAssociation> elements() {
        return Arrays.asList(toArray(new DerivedAssociation[0]));
    }

}
